@@ -106,31 +106,24 @@ impl<'a> Storage for AzLmdbStorage<'a> {
 }
 
 fn _f_authorize(env: &mut Environment, uri: &str, user_uri: &str, request_access: u8, _is_check_for_reload: bool, trace: &mut Trace) -> Result<u8, i64> {
-    let db_handle;
-
-    match env.get_default_db(DbFlags::empty()) {
-        Ok(db_handle_res) => {
-            db_handle = db_handle_res;
-        },
+    let db_handle = match env.get_default_db(DbFlags::empty()) {
+        Ok(db_handle_res) => db_handle_res,
         Err(e) => {
             error!("Authorize: Err opening db handle: {:?}", e);
             //            thread::sleep(time::Duration::from_secs(3));
             //            error!("Retry");
             return Err(-1);
         },
-    }
+    };
 
-    let txn;
-    match env.get_reader() {
-        Ok(txn1) => {
-            txn = txn1;
-        },
+    let txn = match env.get_reader() {
+        Ok(txn1) => txn1,
         Err(e) => {
             error!("Authorize:CREATING TRANSACTION {:?}", e);
             error!("reopen db");
             return Err(-1);
         },
-    }
+    };
 
     let db = txn.bind(&db_handle);
     let storage = AzLmdbStorage {
